@@ -65,7 +65,7 @@ class DBAPICursor(with_metaclass(abc.ABCMeta, object)):
     @property
     def rowcount(self):
         """By default, return -1 to indicate that this is not supported."""
-        return -1
+        return self.rowcount
 
     @abc.abstractmethod
     def execute(self, operation, parameters=None):
