@@ -47,6 +47,7 @@ class DataInputStream:
 
 def get_query_columns_info(buffer):
     result_meta_bytes = DataInputStream(buffer)
+    rowcount = result_meta_bytes.read_long()
     field_count = result_meta_bytes.read_int()
     columns_description = list()
 
@@ -55,7 +56,7 @@ def get_query_columns_info(buffer):
         col += ":" + result_meta_bytes.read_utf().decode()
         columns_description.append(col)
 
-    return columns_description
+    return rowcount, columns_description
 
 
 def read_values_from_array(query_columns_description: list, dis: DataInputStream) -> list:
@@ -104,9 +105,9 @@ def read_rows_from_batch(query_columns_description: list, dis: DataInputStream)
             row = read_values_from_array(query_columns_description, dis)
             rows.append(row)
         #   if rows become 1000, break it
-        #     if len(rows) == 1000:
-        #         _logger.info("Read Batch - Breaking the loop after 1000 records")
-        #         break
+            if len(rows) == 1000:
+                _logger.info("Read Batch - Breaking the loop after 1000 records")
+                break
         is_row_present = dis.read_byte()
 
     return rows
