@@ -329,70 +329,42 @@ class Cursor(common.DBAPICursor):
         buffer = BytesIO(buffer)
         dis = DataInputStream(buffer)
 
+        # one batch retrieves the predefined set of rows
         self._batch = read_rows_from_batch(self._query_columns_description, dis)
 
     def fetchall(self):
         _logger.info("fetching all")
         return self._fetch_all()
 
-    # def fetchoneOld(self):
-    #     _logger.info("fetching one")
-    #     if len(self._batch) == 0:
-    #         self.fetch_batch()
-    #         if len(self._batch) == 0:
-    #             return None
-    #     self.rows_count += len(self._batch)
-    #     if self.rows_count <= 1000:
-    #         row = self._batch.pop()
-    #     else:
-    #         row = None
-    #         # reset row counter for next query execution
-    #         self.rows_count = 0
-    #     return row
-
     def fetchone(self):
-        _logger.info("fetch returning the batch itself")
+        _logger.info("fetch One returning the batch itself which is limited by predefined no.of rows")
         if len(self._batch) == 0:
             self.fetch_batch()
             if len(self._batch) == 0:
                 return None
-        # # in order to stop fetching next batch, we are limiting to one batch - 1000 records
-        # self.rows_count += len(self._batch)
-        # if self.rows_count <= 1000:
-        #     row = self._batch
-        # else:
-        #     row = None
-        #     # reset row counter for next query execution
-        #     self.rows_count = 0
-        records = []
-        row = self._batch.pop()
-        for i in row:
-            self.rows_count += 1
-            if self.rows_count <= 1000:
-                records.append(i)
-                # return row
-                return records
-            else:
-                return None
+        batchRecords = self._batch
+        return batchRecords
 
-    def poll(self, get_progress_update=True):
-        """Poll for and return the raw status data provided by the Hive Thrift REST API.
-        :returns: ``ttypes.TGetOperationStatusResp``
-        :raises: ``ProgrammingError`` when no query has been started
-        .. note::
-            This is not a part of DB-API.
-        """
-        pass
 
-    def fetch_logs(self):
-        """Retrieve the logs produced by the execution of the query.
-        Can be called multiple times to fetch the logs produced after the previous call.
-        :returns: list<str>
-        :raises: ``ProgrammingError`` when no query has been started
-        .. note::
-            This is not a part of DB-API.
-        """
-        pass
+def poll(self, get_progress_update=True):
+    """Poll for and return the raw status data provided by the Hive Thrift REST API.
+    :returns: ``ttypes.TGetOperationStatusResp``
+    :raises: ``ProgrammingError`` when no query has been started
+    .. note::
+        This is not a part of DB-API.
+    """
+    pass
+
+
+def fetch_logs(self):
+    """Retrieve the logs produced by the execution of the query.
+    Can be called multiple times to fetch the logs produced after the previous call.
+    :returns: list<str>
+    :raises: ``ProgrammingError`` when no query has been started
+    .. note::
+        This is not a part of DB-API.
+    """
+    pass
 
 
 class Error(Exception):
@@ -413,13 +385,12 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("select * from call_center;")
+    cursor.execute("select * from date_dim;")
     bdata = cursor.fetchone()
     try:
-        while len(bdata) > 0:
+        #if len(bdata) < 1000:
             print(bdata)
-            print('total columns in the resultset ', len(bdata))
-            bdata = cursor.fetchone()
+            print('total rows in the batch resultset ', len(bdata))
             r_count = cursor.rowcount()
             print('total row count', r_count)
             # list(islice(iter(bdata, None), 10000))
